@@ -1,4 +1,6 @@
-use std::{convert::From, io};
+use std::{convert::From, io, str::Utf8Error};
+
+use geozero::error::GeozeroError;
 
 #[derive(Debug)]
 pub enum Error {
@@ -9,7 +11,7 @@ pub enum Error {
     UnknownEntityFormat,
     InvalidWkt,
     MissingArgument,
-    InvalidNumberFormat,
+    InvalidNumberFormat(String),
     InputTooLarge,
     IOError,
     JSONParseError,
@@ -24,6 +26,7 @@ pub enum Error {
     NoInputGiven,
     ShapefileReaderError(String),
     ProgramError(String),
+    InvalidInput(String),
 }
 
 impl From<io::Error> for Error {
@@ -43,3 +46,15 @@ impl From<reqwest::Error> for Error {
         Error::HTTPError
     }
 }
+
+impl From<GeozeroError> for Error {
+    fn from(e: GeozeroError) -> Self {
+        Error::ProgramError(format!("{}", e))
+    }
+}
+
+impl From<std::str::Utf8Error> for Error {
+    fn from(e: Utf8Error) -> Self {
+        Error::ProgramError(format!("{}", e))
+    }
+}
