@@ -1,16 +1,19 @@
+#![allow(unreachable_code)]
+#![allow(dead_code)]
+#![allow(unused_imports)]
+pub mod bbox;
 pub mod browser_open;
 pub mod centroid;
 pub mod commands;
 pub mod contains;
-pub mod distance;
 pub mod coord_count;
+pub mod distance;
 pub mod entity;
 pub mod error;
+pub mod fgb;
 pub mod geohash;
 pub mod input;
-pub mod intersection;
 pub mod par;
 pub mod reader;
 pub mod simplify;
 pub mod text;
-pub mod bbox;
