@@ -23,6 +23,7 @@ fn run(matches: ArgMatches) -> Result<(), Error> {
         ("measure", Some(m)) => commands::measure::run(m),
         ("bbox", Some(m)) => commands::bbox::run(m),
         ("shp", Some(m)) => commands::shp::run(m),
+        ("fgb", Some(m)) => commands::fgb::run(m),
         _ => Err(Error::UnknownCommand),
     }
 }
@@ -103,6 +104,24 @@ fn main() {
                         .help("Entity to check intersections.\nMust be Geohash, WKT, or GeoJSON.\nMust be a POLYGON or MULTIPOLYGON.")
                         .index(1)
                 )
+        )
+        .subcommand(
+            SubCommand::with_name("dwithin")
+                .about("Output only points (from STDIN) which fall within a QUERY entity (as command-line ARG)")
+                .after_help(text::FILTER_DWITHIN_AFTER_HELP)
+                .arg(
+                    Arg::with_name("query")
+                        .help("Feature(s) to check intersections.\nMust be Geohash, WKT, or GeoJSON.")
+                        .index(1)
+                )
+                .arg(
+                    Arg::with_name("radius")
+                        .help("Radius in meters")
+                        .takes_value(true)
+                        .required(true)
+                        .long("radius")
+                        .short("r")
+                )
         );
 
     let json = SubCommand::with_name("json")
@@ -158,7 +177,8 @@ fn main() {
                 .help(text::SIMPLIFY_EPSILON_ARG_HELP)
                 .required(true)
                 .index(1),
-        ).arg(
+        )
+        .arg(
             Arg::with_name("to_coord_count")
                 .long("to-coord-count")
                 .required(false)
@@ -168,25 +188,57 @@ fn main() {
 
     let bbox = SubCommand::with_name("bbox")
         .about("Generate bounding boxes for geometries")
-        .arg(Arg::with_name("embed")
-             .long("embed")
-             .short("e")
-             .help("Print inputs as GeoJSON features and include the bbox in the GeoJSON bbox field"))
-        .arg(Arg::with_name("all")
-             .long("all")
-             .short("a")
-             .help("Give a single bbox for all input geometries rather than 1 bbox per input"))
+        .arg(Arg::with_name("embed").long("embed").short("e").help(
+            "Print inputs as GeoJSON features and include the bbox in the GeoJSON bbox field",
+        ))
+        .arg(
+            Arg::with_name("all")
+                .long("all")
+                .short("a")
+                .help("Give a single bbox for all input geometries rather than 1 bbox per input"),
+        )
         .after_help(text::BBOX_AFTER_HELP);
 
     let shp = SubCommand::with_name("shp")
         .about("Read a shapefile and convert to GeoJSON")
         .arg(
             Arg::with_name("path")
-                .help("path to the .shp file -- expects .dbf file to be adjacent.")
+                .help("output file, e.g. data.fgb")
                 .required(true)
                 .index(1),
         );
 
+    let fgb = SubCommand::with_name("fgb")
+        .about("Reading and Writing FlatGeoBuf")
+        .subcommand(
+            SubCommand::with_name("write")
+                .about("Write GeoJSON data to a binary flatgeobuf file")
+                .arg(
+                    Arg::with_name("path")
+                        .help("output path")
+                        .required(true)
+                        .index(1),
+                ),
+        )
+        .subcommand(
+            SubCommand::with_name("read")
+                .about("Read a binary flatgeobuf file to GeoJSON")
+                .arg(
+                    Arg::with_name("path")
+                        .help("input path to .fgb file")
+                        .required(true)
+                        .index(1),
+                )
+                .arg(
+                    Arg::with_name("bbox")
+                        .allow_hyphen_values(true)
+                        .long("bbox")
+                        .required(false)
+                        .takes_value(true)
+                        .help("Comma-separated bounding box: minLon,minLat,maxLon,maxLat"),
+                ),
+        );
+
     let matches = App::new("geoq")
         .version(VERSION)
         .setting(AppSettings::SubcommandRequiredElseHelp)
@@ -205,6 +257,7 @@ fn main() {
         .subcommand(simplify)
         .subcommand(bbox)
         .subcommand(shp)
+        .subcommand(fgb)
         .get_matches();
 
     if let Err(e) = run(matches) {
